# Templates for the LinkML documentation generator

Use this folder to store templates to customize the generated model documentation.
The templates are written in Jinja2 and are used to generate the HTML documentation for the schema.

The default templates are available in the [linkml repository](https://github.com/linkml/linkml/tree/main/linkml/generators/docgen).
If you want to use these as a starting point, you can copy them into this folder and modify them as needed.
